@@ -58,7 +58,7 @@ use --force to overwrite. See man page for full list of options.\n";
 #include "libimagequant.h" /* if it fails here, run: git submodule update; ./configure; or add -Ilib to compiler flags */
 #include "pngquant_opts.h"
 
-char *PNGQUANT_VERSION = LIQ_VERSION_STRING " (September 2021)";
+char *PNGQUANT_VERSION = LIQ_VERSION_STRING " (January 2023)";
 
 static pngquant_error prepare_output_image(liq_result *result, liq_image *input_image, rwpng_color_transform tag, png8_image *output_image);
 static void set_palette(liq_result *result, png8_image *output_image);
@@ -346,16 +346,6 @@ pngquant_error pngquant_main_internal(struct pngquant_options *options, liq_attr
         liq_result_destroy(tmp_quantize);
     }
 
-#ifdef _OPENMP
-    // if there's a lot of files, coarse parallelism can be used
-    if (options->num_files > 2*omp_get_max_threads()) {
-        omp_set_nested(0);
-        omp_set_dynamic(1);
-    } else {
-        omp_set_nested(1);
-    }
-#endif
-
     unsigned int error_count=0, skipped_count=0, file_count=0;
     pngquant_error latest_error=SUCCESS;
 
